@@ -13,15 +13,15 @@ from init_helpers.dict_to_dataclass import get_converter
 
 
 class NetrisProviderConnector:
-    @dataclass(kw_only=True)
-    class Config(AbmServiceConnector.Config):
-        server_name: str
+    Config = AbmServiceConnector.Config
 
-    Context = AbmServiceConnector.Context
+    @dataclass
+    class Context(AbmServiceConnector.Context):
+        project_name: str
 
     def __init__(self, config: Config, context: Context) -> None:
-        self._config = config
-        self._context = context
+        self.config = config
+        self.context = context
         self._connector = AbmServiceConnector(config, context)
 
     async def get_camera_outer_id_to_inner_id(self, outer_ids: list[str]) -> dict[str, int]:
@@ -37,4 +37,4 @@ class NetrisProviderConnector:
         return get_converter(dict[int, str])(camera_inner_id_to_outer_id)
 
     def _prepare_headers(self) -> dict[str, str]:
-        return {"server_name": self._config.server_name}
+        return {"server_name": self.context.project_name}
